@@ -5,6 +5,12 @@ versions of django/python, and compatibility wrappers around optional packages.
 # flake8: noqa
 import django
 
+# location of patterns, url, include changes in 1.4 onwards
+try:
+    from django.conf.urls import patterns, url, include
+except:
+    from django.conf.urls.defaults import patterns, url, include
+
 # django-filter is optional
 try:
     import django_filters
